from fairies.nlp_clean_data import (
    clean_data,
    removeLineFeed
)

from fairies.file_utils import (
    write_json,
    read_json,
    write_txt,
    read_txt,
    reSort,
    get_file_list,
    get_file_size,
    download_pdf,
    unzip_file,
    an_garcode,
    get_listdir
)

from fairies.nlp_utils import (
    isHasMark,
    label2id,
    is_chinese,
    find_lcs,
    random_build_data
)

from fairies.extract_utils import (
    read_pdf_by_box,
    read_html,
    read_pdf_by_line,
    read_xml,
    removeLineFeed
)

from fairies.translate import (
    en_to_zh,
    zh_to_en
)

from fairies.excel_utils import (
    write_excel,
    read_excel
)

from fairies.decorator_utils import(
    clock
)

from fairies.nlp_jieba_utils import(
    jieba_init,
    jieba_add_words,
    jieba_cut
)

from fairies.nlp_data_processing import(
    text_len_analysis,
    split_to_paragraph,
    split_to_sents,
    split_to_subsents,
    dict_bar
)

from fairies.print_utils import (
    print_to_log
)


import jieba

def jieba_init():
    
    """
        初始化jieba分词字典 提前加载,不会在调用时再加载
    """
    
    jieba.initialize()

def jieba_cut(text):
    
    """
        jieba分词普通模式
        传入text 返回list
    """
    res = []
    seg_list = jieba.cut(text, cut_all=False)
    for i in seg_list:
        res.append(i)

    return res    

def jieba_add_words(lists):
    for i in lists:
        jieba.suggest_freq(i, True)


import time
import os
import time
import logging
import sys
from functools import wraps
import traceback

def clock(func):
    """ 计算时间装饰器 """
    def clocked(*args, **kwargs):
        start = time.time()
        result = func(*args, **kwargs)
        end = time.time()
        print(func.__name__, int(end - start))
        return  result
    return clocked



import datetime

def print_to_log(out_put):   
    
    # 增量写入

    log_name = 'log_' + datetime.datetime.now().strftime('%Y') + '_' + datetime.datetime.now().strftime('%m') + '_' + datetime.datetime.now().strftime('%d') + '.txt'

    try:

        man_out = open(log_name,"a")
        print('Log',out_put,file=man_out)
        man_out.close()

    except IOError:
        print ('data file is not exist')



import re

def clean_data(text):

    temp = ['\uf043','\uf020','\uf076','\uf046','\uf075','\uf06c','\uf09f','\uf0d8','\uf072','\uf077','．','…','„',' ']
    List = re.findall(r'[(]cid.*?[)]',text)
    List = List + temp
    for l in List:
        text = text.replace(l,'')
    text = removeLineFeed(text)
    return text            

def removeLineFeed(text):
    
    """去除换行 tab键"""
    k = text.replace('\r','').replace('\n','').replace('\t',' ')
    return k